@@ -31,6 +31,8 @@
 #include "gmainwindow.h"
 #include "gcontainer.h"
 
+//#define DEBUG_FIND 1
+
 static GList *_arrange_list = NULL;
 
 static gControl *get_next_child_widget (gContainer *gtk_control, int *gtk_index)
@@ -688,6 +690,8 @@ void gContainer::insert(gControl *child, bool realize)
 		child->setDesign(true);
 	
 	child->updateDirection();
+	
+	updateDesignChildren();
 }
 
 void gContainer::remove(gControl *child)
@@ -695,15 +699,16 @@ void gContainer::remove(gControl *child)
 	g_ptr_array_remove(_children, child);
 }
 
-
 gControl *gContainer::find(int x, int y, bool skip_ignore_mouse)
 {
 	int i;
 	gControl *ch;
 	
-	//fprintf(stderr, "gContainer::find: %s (C %d %d %d %d) (S %d %d): %d %d\n", name(), clientX(), clientY(), clientWidth(), clientHeight(), scrollX(), scrollY(), x, y);
+#if DEBUG_FIND
+	fprintf(stderr, "gContainer::find: %s (C %d %d %d %d) (S %d %d): %d %d\n", name(), clientX(), clientY(), clientWidth(), clientHeight(), scrollX(), scrollY(), x, y);
+#endif
 
-	x -= clientX();
+	/*x -= clientX();
 	y -= clientY();
 	
 	if (gApplication::_button_grab != this)
@@ -712,6 +717,9 @@ gControl *gContainer::find(int x, int y, bool skip_ignore_mouse)
 			return NULL;
 	}
 	
+	x += clientX();
+	y += clientY();*/
+	
 	if (_scroll)
 	{
 		x += scrollX();
@@ -721,17 +729,23 @@ gControl *gContainer::find(int x, int y, bool skip_ignore_mouse)
 	for (i = childCount() - 1; i >= 0; i--)
 	{
 		ch = child(i);
-		//fprintf(stderr, "test: %s %d: %d %d %d %d / %d %d\n", ch->name(), ch->isVisible(), ch->x(), ch->y(), ch->width(), ch->height(), x, y);
+#if DEBUG_FIND
+		fprintf(stderr, "test: %s %d: %d %d %d %d / %d %d\n", ch->name(), ch->isVisible(), ch->x(), ch->y(), ch->width(), ch->height(), x, y);
+#endif
 		if (skip_ignore_mouse && ch->isIgnoreMouse())
 			continue;
 		if (ch->isVisible() && x >= ch->left() && y >= ch->top() && x < (ch->left() + ch->width()) && y < (ch->top() + ch->height()))
 		{
-			//fprintf(stderr, "--> %s\n", ch->name());
+#if DEBUG_FIND
+			fprintf(stderr, "--> %s\n", ch->name());
+#endif
 			return ch;
 		}
 	}
-	
-	//fprintf(stderr, "--> NULL\n");
+
+#if DEBUG_FIND
+	fprintf(stderr, "--> NULL\n");
+#endif
 	return NULL;
 }
 
@@ -955,10 +969,16 @@ void gContainer::updateDesignChildren()
 	if (!isUser() && !isDesignIgnore())
 		return;
 	
+	if (isDesignIgnore())
+	{
+		for (i = 0; i < childCount(); i++)
+			child(i)->setDesign(true);
+	}
+
 	if (isUserContainer() && !_proxyContainer)
 		return;
 	
-	cont = isDesignIgnore() ? this : proxyContainer();
+	cont = proxyContainer();
 	
 	for (i = 0; i < cont->childCount(); i++)
 		cont->child(i)->setDesign(true);
