@@ -980,9 +980,10 @@ void CPROCESS_wait_for(CPROCESS *process, int timeout)
 {
 	int ret;
 	int sigfd;
+	WATCH_TIMEOUT wt;
 
 	#ifdef DEBUG_ME
-	fprintf(stderr, "Waiting for %d\n", process->pid);
+	fprintf(stderr, "-------- Waiting for %d timeout %d\n", process->pid, timeout);
 	#endif
 	
 	// If CPROCESS_check() caught the process end, process->running is not set yet, because
@@ -991,6 +992,8 @@ void CPROCESS_wait_for(CPROCESS *process, int timeout)
 	if (process->wait)
 		return;
 
+	WATCH_timeout(&wt, timeout);
+	
 	OBJECT_REF(process);
 
 	ON_ERROR_1(error_CPROCESS_create, process)
@@ -1006,7 +1009,9 @@ void CPROCESS_wait_for(CPROCESS *process, int timeout)
 			#endif
 			if (_init)
 				SIGNAL_check(SIGCHLD);
-			ret = WATCH_process(sigfd, process->out, process->err, timeout);
+			
+			ret = WATCH_process(sigfd, process->out, process->err, &wt);
+			
 			#ifdef DEBUG_ME
 			fprintf(stderr, "Watch process %d ->%s%s%s%s\n", process->pid, ret & WP_END ? " END" : "", ret & WP_OUTPUT ? " OUTPUT" : "", ret & WP_ERROR ? " ERROR" : "", ret & WP_TIMEOUT ? " TIMEOUT" : "");
 			#endif
