@@ -354,8 +354,6 @@ static bool init_breakpoint(DEBUG_BREAK *brk)
 	PCODE *addr = NULL;
 	FUNCTION *func;
 
-	//fprintf(stderr, "init_breakpoint: id = %d\n", brk->id);
-
 	if (!brk->class)
 	{
 		brk->class = (CLASS *)GB_DEBUG.LookClass(brk->comp, brk->name);
@@ -521,8 +519,7 @@ void DEBUG_init_breakpoints(CLASS *class)
 	for (i = 0; i < GB.Count(_breakpoints); i++)
 	{
 		brk = &_breakpoints[i];
-		//fprintf(stderr, "%s / %s\n", brk->name, class->name);
-		if (strcmp(brk->name, class->name))
+		if (GB.StrCaseCmp(brk->name, class->name))
 			continue;
 		if (!same_component(brk->comp, class->component ? class->component->name : NULL))
 			continue;
